@@ -9,6 +9,7 @@
 #include <QFuture>
 #include <QFutureWatcher>
 
+#include <iostream>
 #include <vector>
 
 #include <ytmusic.h>
@@ -123,6 +124,8 @@ public:
 
     QFuture<Lyrics> fetchLyrics(const QString &browseId);
 
+    QFuture<QString> version();
+
     Q_SIGNAL void errorOccurred(const QString &error);
 
 protected:
