@@ -10,6 +10,9 @@
 #include "asyncytmusic.h"
 #include "playlistutils.h"
 
+#include <QStringBuilder>
+
+
 PlaylistModel::PlaylistModel(QObject *parent)
     : AbstractYTMusicModel(parent)
 {
@@ -99,3 +102,13 @@ QString PlaylistModel::title() const
 {
     return QString::fromStdString(m_playlist.title);
 }
+
+QUrl PlaylistModel::webUrl() const
+{
+    return QUrl(YTMUSIC_WEB_BASE_URL % "playlist?list=" % playlistId());
+}
+
+playlist::Playlist PlaylistModel::playlist() const
+{
+    return m_playlist;
+}
